@@ -36,9 +36,16 @@ get_classification <- function(inchi_key)
   }
 
   if (response$status_code == 200) {
-    message(crayon::green(clisymbols::symbol$tick, inchi_key))
     text_content <- httr::content(response, 'text')
 
+    if (text_content == '{}') {
+      message(crayon::red(clisymbols::symbol$cross, inchi_key))
+      return(invisible(NULL))
+    } else{
+      message(crayon::green(clisymbols::symbol$tick, inchi_key))
+    }
+
+
     json_res <- jsonlite::fromJSON(text_content)
 
     classification <- parse_json_output(json_res)
@@ -56,22 +63,38 @@ get_classification <- function(inchi_key)
 
     object@classification <- classification
 
-    object@direct_parent <- json_res$direct_parent
+    if (length(json_res$direct_parent) > 0) {
+      object@direct_parent <- json_res$direct_parent
+    }
 
-    object@alternative_parents <-
-      tibble::tibble(
-        name = json_res$alternative_parents$name,
-        description = json_res$alternative_parents$description,
-        chemont_id = json_res$alternative_parents$chemont_id,
-        url = json_res$alternative_parents$url
-      )
+    if (length(json_res$alternative_parents) > 0) {
+      object@alternative_parents <-
+        tibble::tibble(
+          name = json_res$alternative_parents$name,
+          description = json_res$alternative_parents$description,
+          chemont_id = json_res$alternative_parents$chemont_id,
+          url = json_res$alternative_parents$url
+        )
+    } else{
+      object@alternative_parents <- tibble::tibble()
+    }
 
-    object@predicted_chebi <- json_res$predicted_chebi_terms
+    if (length(json_res$predicted_chebi_terms) > 0) {
+      object@predicted_chebi <- json_res$predicted_chebi_terms
+    } else{
+      object@predicted_chebi <- vector(mode = 'character')
+    }
 
-    object@external_descriptors <- parse_external_desc(json_res)
 
-    object@description <- json_res$description
+    if (length(json_res$external_descriptors) > 0) {
+      object@external_descriptors <- parse_external_desc(json_res)
+    } else{
+      object@external_descriptors <- tibble::tibble()
+    }
 
+    if (length(json_res$description) > 0) {
+      object@description <- json_res$description
+    }
 
     return(object)
   }
